package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

@FunctionalInterface
/* loaded from: org_apache_commons_lang3_function.jar:org/apache/commons/lang3/function/FailableBiConsumer.class */
public interface FailableBiConsumer<T, U, E extends Throwable> {
    public static final FailableBiConsumer NOP = (t, u) -> {
    };

    void accept(T t, U u) throws Throwable;

    static <T, U, E extends Throwable> FailableBiConsumer<T, U, E> nop() {
        return NOP;
    }

    default FailableBiConsumer<T, U, E> andThen(FailableBiConsumer<? super T, ? super U, E> after) {
        Objects.requireNonNull(after);
        return (obj, obj2) -> {
            accept(obj, obj2);
            after.accept(obj, obj2);
        };
    }
}
